@@ -1,14 +1,19 @@
 #'@title Calculate G Efficiency
 #'
-#'@description Either calculates G-Efficiency by Monte Carlo sampling from the design space (ignoring constraints), searching for the maximum point (slower but higher quality), or by using a user-specified candidate set for the design space (fastest).
+#'@description Either calculates G-Efficiency by Monte Carlo sampling from the design space (ignoring constraints),
+#'searching for the maximum point (slower but higher quality), or by using a user-specified candidate set
+#'for the design space (fastest).
 #'@return Normalized run matrix
 #'@keywords internal
-calculate_gefficiency = function(design, calculation_type = "random", randsearches = 1000,  design_space_mm = NULL) {
+calculate_gefficiency = function(design, calculation_type = "random", randsearches = 10000,  design_space_mm = NULL) {
   if(!is.null(attr(design, "runmatrix"))) {
     run_matrix = attr(design, "runmatrix")
   } else {
     run_matrix = design
   }
+  if(is.null(randsearches)) {
+    randsearches = 10000
+  }
   variables = all.vars(get_attribute(design,"model"))
   designmm = get_attribute(design,"model.matrix")
   modelentries = names(calculate_level_vector(run_matrix,get_attribute(design,"model"), FALSE))
@@ -18,7 +23,7 @@ calculate_gefficiency = function(design, calculation_type = "random", randsearch
   factorvars = attr(design,"contrastslist")
   variables = variables[!variables %in% names(factorvars)]
   rand_vector = function(factorlist, model_entries_mul) {
-    fulloutput = unlist(lapply(model_entries_mul, lazyeval::lazy_eval, data = factorlist))
+    fulloutput = unlist(lapply(model_entries_mul, \(x) eval(parse(text=x), envir = factorlist)))
     matrix(fulloutput,1,length(fulloutput))
   }
   calculate_optimality_for_point = function(x, infval = FALSE) {
@@ -47,7 +52,7 @@ calculate_gefficiency = function(design, calculation_type = "random", randsearch
   if(calculation_type == "random") {
     vals = list()
     lowest = 100
-    for(i in 1:randsearches) {
+    for(i in seq_len(randsearches)) {
       vals[[i]] = calculate_optimality_for_point(2*runif(length(variables))-1)
       if(vals[[i]] < lowest) {
         lowest = vals[[i]]
@@ -58,7 +63,7 @@ calculate_gefficiency = function(design, calculation_type = "random", randsearch
   if(calculation_type == "optim") {
     vals = list()
     lowest = 100
-    for(i in 1:randsearches) {
+    for(i in seq_len(randsearches)) {
       vals[[i]] = optim(2*runif(length(variables))-1,calculate_optimality_for_point, method = "SANN")$value
       if(vals[[i]] < lowest) {
         lowest = vals[[i]]
