@@ -4,26 +4,27 @@
 #'@param run_matrix_processed The design
 #'@return Vector of numbers indicating split plot layers
 #'@keywords internal
-calculate_split_columns = function(run_matrix_processed, blockgroups) {
-  lowest_level = length(lapply(blockgroups, length)) + 1
+calculate_split_columns = function(run_matrix_processed, blockgroups, blockstructure) {
+  lowest_level = length(blockgroups) + 1
   splitlayer = rep(lowest_level,ncol(run_matrix_processed))
   allsplit = TRUE
-  for (i in 1:length(blockgroups)) {
-    currentrow = 1
+  for (i in seq_len(length(blockgroups))) {
     isblockcol = rep(TRUE,ncol(run_matrix_processed))
     temp_block_str = blockgroups[[i]]
-    for (j in 1:length(temp_block_str)) {
+    temp_block_str_names = names(temp_block_str)
+    for (j in seq_len(length(temp_block_str))) {
+      block_name = temp_block_str_names[j]
       if (temp_block_str[j] - 1 > 0) {
-        for (k in 0:(temp_block_str[j] - 2)) {
-          isblockcol = isblockcol & run_matrix_processed[currentrow + k, ] == run_matrix_processed[currentrow + 1 + k, ]
-        }
+        block_idx = which(blockstructure[,i] == block_name)
+        is_constant = lapply(apply(run_matrix_processed[block_idx,, drop = FALSE], 2, unique, simplify = FALSE), length) == 1
+        isblockcol = isblockcol & is_constant
       }
-      currentrow = currentrow + temp_block_str[j]
     }
     if(length(splitlayer[isblockcol & splitlayer == lowest_level]) < 1) {
       allsplit = FALSE
     }
     splitlayer[isblockcol & splitlayer == lowest_level] = i
   }
+  #Now this also returns the level each layer is nested in (zero indicating intercept)
   return(list(splitlayer=splitlayer, allsplit=allsplit))
 }
